@@ -1,6 +1,8 @@
 import base64
 import copy
+import math
 import pathlib
+import urllib.request
 from collections import namedtuple
 from pinout import manager, templates
 
@@ -16,7 +18,7 @@ class TransformMixin:
         matrix=None,
         translate=None,
         scale=(1, 1),
-        rotate=None,
+        rotate=0,
         skewx=None,
         skewy=None,
         **kwargs,
@@ -40,7 +42,7 @@ class Layout(TransformMixin):
         self.y = y
         self.children = []
         self.defs = []
-        self.config = {}
+        self.config = kwargs.pop("config", {})
 
     def add(self, instance):
         self.children.append(instance)
@@ -107,6 +109,14 @@ class Layout(TransformMixin):
         x1, y1, x2, y2 = self.bounding_coords()
         return BoundingRect(x1, y1, x2 - x1, y2 - y1)
 
+    def rotated_coords(self, x, y):
+        return Coords(
+            x * math.cos(math.radians(-self.rotate))
+            + y * math.sin(math.radians(-self.rotate)),
+            -x * math.sin(math.radians(-self.rotate))
+            + y * math.cos(math.radians(-self.rotate)),
+        )
+
     def bounding_coords(self):
         """Coordinates of the components's bounding rectangle.
 
@@ -128,8 +138,21 @@ class Layout(TransformMixin):
             y.append(self.y + coords.y2 * self.scale.y)
         x.sort()
         y.sort()
+
         try:
-            return BoundingCoords(x[0], y[0], x[-1], y[-1])
+            # Transform with rotate
+            x1, y1, x2, y2 = x[0], y[0], x[-1], y[-1]
+            top_left = self.rotated_coords(x1, y1)
+            top_right = self.rotated_coords(x2, y1)
+            bottom_left = self.rotated_coords(x1, y2)
+            bottom_right = self.rotated_coords(x2, y2)
+            zipped = [
+                sorted(list(coord))
+                for coord in zip(top_left, top_right, bottom_left, bottom_right)
+            ]
+            return BoundingCoords(
+                zipped[0][0], zipped[1][0], zipped[0][-1], zipped[1][-1]
+            )
         except IndexError:
             # There are no children
             return BoundingCoords(0, 0, 0, 0)
@@ -312,7 +335,7 @@ class Text(SvgShape):
 
 
 class Image(SvgShape):
-    """Include a image in the diagram. Access via Diagram.add_image()"""
+    """Include a image in the diagram."""
 
     def __init__(self, path, embed=False, **kwargs):
         super().__init__(**kwargs)
@@ -320,26 +343,35 @@ class Image(SvgShape):
         self.svg_data = None
         self.embed = embed
 
-    def render(self):
-        """Render SVG markup either linking or embedding an image.
+    def loadData(self):
+        """Load image data from URL or local file system."""
+        try:
+            with open(self.path, "rb") as f:
+                return f.read()
+        except OSError:
+            try:
+                with urllib.request.urlopen(self.path) as f:
+                    return f.read()
+            except urllib.error.HTTPError as e:
+                print(e.code)
 
-        :return: SVG markup
-        :rtype: string
-        """
+    def render(self):
+        """Render SVG markup either linking or embedding an image."""
         media_type = pathlib.Path(self.path).suffix[1:]
-        path = pathlib.Path(self.path)
         tplt = templates.get("image.svg")
+
         if self.embed:
             if media_type == "svg":
-                with path.open() as f:
-                    data = f.read()
+                data = self.loadData()
                 # Extract JUST the <svg> markup with no <XML> tag
                 import xml.etree.ElementTree as ET
 
                 tree = ET.fromstring(data)
                 self.svg_data = ET.tostring(tree)
             else:
-                encoded_img = base64.b64encode(open(self.path, "rb").read())
-                path = f"data:image/{media_type};base64,{encoded_img.decode('utf-8')}"
+                encoded_img = base64.b64encode(self.loadData())
+                self.path = (
+                    f"data:image/{media_type};base64,{encoded_img.decode('utf-8')}"
+                )
 
         return tplt.render(image=self)
